<?php
/**
 * OOPでBBS (Step5)
 *
 * オブジェクト指向プログラミングで掲示板を作ってみる。
 * ブログでその作り方を晒すために書いたものです。
 * 詳しい事は当該記事を見てください。 
 *
 *
 *           
 * PHP version 5.3
 *
 * LICENSE : このソースはCreative Commons 表示 - 非営利 2.1 日本 Licenseです。
 *           改変は自由ですが営利目的で利用することは出来ません。
 * 
 * @category  Step5
 * @package   OOP-BBS
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 *
 */
 

/**
 * 掲示板をコントロールするクラス
 *
 * ModelとViewの中間に立って仕事を振り分けます。
 * ユーザが起こしたイベントに対して応答し、色々と処理します。
 * 仕分け人なので描画やデータの操作は行いません。
 *
 * <step5>
 * Configクラス作成。iniファイル名は定数でいいかな。
 * Viewに送るメッセージにメッセージタイプを追加。
 * トークンを作るメソッドと２重送信チェックを追加。
 * 
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   Creative Commons BY-NC http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 */

class Controller {
	
	const INIT_FILE = 'bbs.ini';
	
    public function __construct()
    {
		
    }
    
    /**
     * index.phpから実行されるメソッド
     * @return {}
     * @since 1.0 (step1)
     */
    public function execute()
    {
        

        include_once('model.php');
        include_once('view.php');
        include_once('bbs_log.php');
        include_once('config.php');
		
		$iniFilePath = dirname($_SERVER['SCRIPT_FILENAME']).'/lib/'.self::INIT_FILE;
	
		$config = new Config($iniFilePath);//設定
        
        $modelInstance = new Model($config);//モデル
        $viewInstance = new View($config);//ビュー
		
        $message = '';
        
        $viewInstance->setTemplateName('index');//テンプレートをセット
        $modelInstance->setLogfileName($config->get('logfile_name'));//ログファイルをセット
        
        if(isset($_POST['mode']) && $_POST['mode'] != ''){
            
			//トークンの確認
			$token = $modelInstance->clean($_POST['token']);
			
			if($token == @$_COOKIE["_token"]){
				$viewInstance->setSystemMessage('error', '不正な送信です');//エラーをViewに渡す
				
			}else{
			
				switch($_POST['mode']){
					
					case 'write':
						$modelInstance->setPostdata($_POST);//送信内容のセット
								
						if($modelInstance->validation()===true){
							$modelInstance->write();//ログに書き込み
							$viewInstance->setSystemMessage('success', '保存しました');//メッセージをセット
							setcookie("_token", $modelInstance->clean($token));
										
						}else{
							$viewInstance->setSystemMessage('error', $modelInstance->getError());//エラーをViewに渡す
						}
				
					break;
					
					default:
					   
				}
			}
            
        }
        
        $modelInstance->readLog();//ログを読み込む
        $viewInstance->setLog($modelInstance->getLogData());//Viewにログを渡す
		$viewInstance->setToken($this->createToken());//Viewにトークンを渡す
        
        $viewInstance->display();//表示
    
    }
	
	/**
	 * トークンの作成
	 * @return {string} ランダムな半角英数から成る文字列
	 */
	public function createToken()
	{
		return substr(sha1(uniqid().mt_rand()),-13,10);
	}
}

?>